@@ -357,26 +357,17 @@ def ucode_create_problems(lesson, credential, score, base_folder, xp):
             CLog.important(f'Problem `{problem_id}` created')
 
 
-@beestar_group.command(name="get")
-@click.option('-c', '--credential', default='credentials.ini',
-              type=click.Path(dir_okay=False, exists=True),
-              prompt='Credential file', help='Configuration file that contain beestar cookie')
-@click.option('-o', '--output', default='result.html',
-              type=click.Path(dir_okay=False, exists=False),
-              prompt='Output file', help='Output file')
-@click.argument('review_details_url', metavar='{review_details_url}')
-def beestar_get(credential, output, review_details_url):
+@beestar_group.command(name="getall")
+@click.option('-u', '--username', type=click.STRING, help='beestar username')
+@click.option('-p', '--password', type=click.STRING, help='beestar password')
+@click.option('-o', '--output', default='.',
+              type=click.Path(file_okay=False, exists=True),
+              prompt='Output folder', help='Output folder')
+def beestar_get_all(username, password, output):
     """
     sample:
-    ptoolbox bs get -c ../../credentials.ini -o de2.html "https://beestar.org/exam?cmd=startexerciseconfirm&session_num3=5990178713121315&status=FINISH&descID=186&exam_num=2&check_sus=true"
+    ptoolbox bs getall -u email -p pass -o beestar
     """
-    cookie = Beestar.read_credential(credential)
-    if not cookie:
-        return
 
     beestar = Beestar()
-    beestar.login_by_cookie(cookie)
-    beestar.get_review_detail(
-        review_details_url,
-        output
-    )
\ No newline at end of file
+    beestar.get_all_quizzes(username, password, output)
