@@ -12,6 +12,7 @@ from ptoolbox.dsa.dsa_problem import DsaProblem
 from ptoolbox.helpers.clog import CLog
 from ptoolbox.helpers.misc import make_slug
 from ptoolbox.models.general_models import Problem, TestCase
+from ptoolbox.models.question import Question
 
 _logger = logging.getLogger(__name__)
 
@@ -28,26 +29,48 @@ class UCode:
     def get_api_url(self, path):
         return self.api_base_url + path
 
-    def create_problem(self, lesson_id, problem: Union[Problem, str], score=10, xp=100, lang='vi'):
+    def create_problem(self, lesson_id, problem: Union[Question, Problem, str],
+                       score=10, xp=100, lang='vi'):
         if isinstance(problem, str):
             problem: Problem = DsaProblem.load(problem, load_testcase=True)
 
-        data = {
-            "name": problem.name,
-            "type": "code",
-            "statement": problem.statement,
-            "statement_format": "markdown",
-            "input_desc": problem.input_format,
-            "output_desc": problem.output_format,
-            "constraints": problem.constraints,
-            "compiler": "python",
-            "statement_language": lang,
-            "score": score,
-            "solution": problem.solution,
-            "status": "string",
-            "visibility": "public",
-            "ucoin": xp
-        }
+        if isinstance(problem, Problem):
+            data = {
+                "name": problem.name,
+                "type": 'code',
+                "statement": problem.statement,
+                "statement_format": "markdown",
+                "input_desc": problem.input_format,
+                "output_desc": problem.output_format,
+                "constraints": problem.constraints,
+                "compiler": "python",
+                "statement_language": lang,
+                "score": score,
+                "solution": problem.solution,
+                "status": "string",
+                "visibility": "public",
+                "ucoin": xp
+            }
+        elif isinstance(problem, Question):
+            question: Question = problem
+            data = {
+                "name": problem.name,
+                "type": 'code',
+                "statement": problem.statement,
+                "statement_format": "markdown",
+                "input_desc": problem.input_format,
+                "output_desc": problem.output_format,
+                "constraints": problem.constraints,
+                "compiler": "python",
+                "statement_language": lang,
+                "score": score,
+                "solution": problem.solution,
+                "status": "string",
+                "visibility": "public",
+                "ucoin": xp
+            }
+        else:
+            raise Exception(f"Unsupported problem type {type(problem)}")
 
         url = self.get_api_url(f"/lesson-item/{lesson_id}/question")
         response = self.s.post(url, json=data, headers=self._headers)
@@ -90,10 +113,12 @@ class UCode:
 
         return question_id
 
-    def create_problems(self, lesson_id, problems: List[Problem], score=10, xp=100):
+    def create_problems(self, lesson_id, problems: List[Problem], score=10, xp=100, lang="vi"):
         question_ids = []
         for problem in problems:
-            q_id = self.create_problem(self, lesson_id, problem, score, xp)
+            q_id = self.create_problem(self, lesson_id=lesson_id,
+                                       problem=problem,
+                                       score=score, xp=xp, lang=lang)
             question_ids.append(q_id)
 
         return question_ids
